summaryrefslogtreecommitdiff
path: root/chromium/components/autofill/core/browser/browser_autofill_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/components/autofill/core/browser/browser_autofill_manager.h')
-rw-r--r--chromium/components/autofill/core/browser/browser_autofill_manager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/components/autofill/core/browser/browser_autofill_manager.h b/chromium/components/autofill/core/browser/browser_autofill_manager.h
index 883fa92634a..0d968e1ff56 100644
--- a/chromium/components/autofill/core/browser/browser_autofill_manager.h
+++ b/chromium/components/autofill/core/browser/browser_autofill_manager.h
@@ -520,11 +520,11 @@ class BrowserAutofillManager : public AutofillManager,
// profile does not exist.
AutofillProfile* GetProfile(int unique_id);
// Determines whether a fill on |form| initiated from |field| will wind up
// filling a credit card number. This is useful to determine if we will need
// to unmask a card.
bool WillFillCreditCardNumber(const FormData& form,
- const FormFieldData& field);
+ const FormFieldData& triggered_field);
// Fills or previews the credit card form.
// Assumes the form and field are valid.
@@ -520,11 +520,11 @@ class BrowserAutofillManager : public AutofillManager,
// profile does not exist.
AutofillProfile* GetProfile(int unique_id);
- // Determines whether a fill on |form| initiated from |field| will wind up
- // filling a credit card number. This is useful to determine if we will need
- // to unmask a card.
+ // Determines whether a fill on |form| initiated from |triggered_field| will
+ // wind up filling a credit card number. This is useful to determine if we
+ // will need to unmask a card.
bool WillFillCreditCardNumber(const FormData& form,